@@ -22,10 +22,14 @@ use std::sync::{Arc, RwLock};
 
 use crate::prelude::*;
 use crate::protos::*;
+use crate::query_language::BooleanExpression;
 use crate::Channel;
+use crate::IndexFiles;
 
 pub type VectorsReaderPointer = Arc<dyn VectorReader>;
 pub type VectorsWriterPointer = Arc<RwLock<dyn VectorWriter>>;
+pub type ProtosRequest = VectorSearchRequest;
+pub type ProtosResponse = VectorSearchResponse;
 
 #[derive(Clone)]
 pub struct VectorConfig {
@@ -35,18 +39,34 @@ pub struct VectorConfig {
     pub channel: Channel,
 }
 
-pub trait VectorReader:
-    ReaderChild<Request = VectorSearchRequest, Response = VectorSearchResponse>
-{
+// In an ideal world this should be part of the actual request, but since
+// we use protos all the way down the stack here we are. Once the protos use
+// is restricted to only the upper layer, this type won't be needed anymore.
+#[derive(Clone, Default)]
+pub struct VectorsContext {
+    pub filtering_formula: Option<BooleanExpression>,
+}
+
+pub struct MergeMetrics {
+    pub merged: usize,
+    pub left: usize,
+}
+
+pub trait VectorReader: std::fmt::Debug + Send + Sync {
+    fn search(&self, request: &ProtosRequest, context: &VectorsContext) -> NodeResult<ProtosResponse>;
+    fn stored_ids(&self) -> NodeResult<Vec<String>>;
     fn count(&self, vectorset: &str) -> NodeResult<usize>;
 }
 
-pub trait VectorWriter: WriterChild {
+pub trait VectorWriter: std::fmt::Debug + Send + Sync {
+    fn merge(&mut self) -> NodeResult<MergeMetrics>;
+    fn set_resource(&mut self, resource: &Resource) -> NodeResult<()>;
+    fn delete_resource(&mut self, resource_id: &ResourceId) -> NodeResult<()>;
+    fn garbage_collection(&mut self) -> NodeResult<()>;
+    fn count(&self) -> NodeResult<usize>;
+    fn get_segment_ids(&self) -> NodeResult<Vec<String>>;
+    fn get_index_files(&self, ignored_segment_ids: &[String]) -> NodeResult<IndexFiles>;
     fn list_vectorsets(&self) -> NodeResult<Vec<String>>;
     fn remove_vectorset(&mut self, setid: &VectorSetId) -> NodeResult<()>;
-    fn add_vectorset(
-        &mut self,
-        setid: &VectorSetId,
-        similarity: VectorSimilarity,
-    ) -> NodeResult<()>;
+    fn add_vectorset(&mut self, setid: &VectorSetId, similarity: VectorSimilarity) -> NodeResult<()>;
 }
