@@ -22,9 +22,9 @@ use std::sync::Arc;
 
 use nucliadb_core::protos::node_writer_server::NodeWriter;
 use nucliadb_core::protos::{
-    garbage_collector_response, op_status, EmptyQuery, GarbageCollectorResponse, NewShardRequest,
-    NewVectorSetRequest, NodeMetadata, OpStatus, Resource, ResourceId, ShardCleaned, ShardCreated,
-    ShardId, ShardIds, VectorSetId, VectorSetList,
+    garbage_collector_response, merge_response, op_status, EmptyQuery, GarbageCollectorResponse, MergeResponse,
+    NewShardRequest, NewVectorSetRequest, NodeMetadata, OpStatus, Resource, ResourceId, ShardCreated, ShardId,
+    ShardIds, VectorSetId, VectorSetList,
 };
 use nucliadb_core::tracing::{self, Span, *};
 use nucliadb_core::Channel;
@@ -39,7 +39,7 @@ use crate::shards::metadata::ShardMetadata;
 use crate::shards::providers::shard_cache::ShardWriterCache;
 use crate::shards::writer::ShardWriter;
 use crate::telemetry::run_with_telemetry;
-use crate::utils::list_shards;
+use crate::utils::{get_primary_node_id, list_shards, read_host_key};
 
 pub struct NodeWriterGRPCDriver {
     shards: Arc<ShardWriterCache>,
@@ -77,10 +77,7 @@ impl NodeWriterGRPCDriver {
     }
 }
 
-fn obtain_shard(
-    shards: Arc<ShardWriterCache>,
-    id: impl Into<String>,
-) -> Result<Arc<ShardWriter>, tonic::Status> {
+fn obtain_shard(shards: Arc<ShardWriterCache>, id: impl Into<String>) -> Result<Arc<ShardWriter>, tonic::Status> {
     let id = id.into();
 
     let shard = shards.get(&id).map_err(|error| {
@@ -95,10 +92,7 @@ fn obtain_shard(
 
 #[tonic::async_trait]
 impl NodeWriter for NodeWriterGRPCDriver {
-    async fn new_shard(
-        &self,
-        request: Request<NewShardRequest>,
-    ) -> Result<Response<ShardCreated>, Status> {
+    async fn new_shard(&self, request: Request<NewShardRequest>) -> Result<Response<ShardCreated>, Status> {
         send_analytics_event(AnalyticsEvent::Create).await;
         let request = request.into_inner();
         let kbid = request.kbid.clone();
@@ -140,9 +134,7 @@ impl NodeWriter for NodeWriterGRPCDriver {
         let shard_id_clone = shard_id.id.clone();
         let deleted = tokio::task::spawn_blocking(move || shards.delete(&shard_id_clone))
             .await
-            .map_err(|error| {
-                tonic::Status::internal(format!("Error deleted shard {}: {error:?}", shard_id.id))
-            })?;
+            .map_err(|error| tonic::Status::internal(format!("Error deleted shard {}: {error:?}", shard_id.id)))?;
 
         match deleted {
             Ok(_) => {
@@ -157,38 +149,18 @@ impl NodeWriter for NodeWriterGRPCDriver {
         }
     }
 
-    async fn clean_and_upgrade_shard(
-        &self,
-        request: Request<ShardId>,
-    ) -> Result<Response<ShardCleaned>, Status> {
-        let shard_id = request.into_inner().id;
-
-        // No need to load shard to upgrade it
-        let shards = Arc::clone(&self.shards);
-        let shard_id_clone = shard_id.clone();
-        let upgraded = tokio::task::spawn_blocking(move || shards.upgrade(&shard_id_clone))
-            .await
-            .map_err(|error| {
-                tonic::Status::internal(format!("Error deleted shard {}: {error:?}", shard_id))
-            })?;
-
-        match upgraded {
-            Ok(upgrade_details) => Ok(tonic::Response::new(upgrade_details)),
-            Err(error) => Err(tonic::Status::internal(error.to_string())),
-        }
-    }
-
-    async fn list_shards(
-        &self,
-        _request: Request<EmptyQuery>,
-    ) -> Result<Response<ShardIds>, Status> {
+    async fn list_shards(&self, _request: Request<EmptyQuery>) -> Result<Response<ShardIds>, Status> {
         let shard_ids = list_shards(self.shards.shards_path.clone())
             .await
             .into_iter()
-            .map(|id| ShardId { id })
+            .map(|id| ShardId {
+                id,
+            })
             .collect();
 
-        Ok(tonic::Response::new(ShardIds { ids: shard_ids }))
+        Ok(tonic::Response::new(ShardIds {
+            ids: shard_ids,
+        }))
     }
 
     // Incremental call that can be call multiple times for the same resource
@@ -202,16 +174,12 @@ impl NodeWriter for NodeWriterGRPCDriver {
         let write_task = || {
             run_with_telemetry(info, move || {
                 let shard = obtain_shard(shards, shard_id_clone)?;
-                shard
-                    .set_resource(&resource)
-                    .and_then(|()| shard.get_opstatus())
+                shard.set_resource(&resource).and_then(|()| shard.get_opstatus())
             })
         };
         let status = tokio::task::spawn_blocking(write_task)
             .await
-            .map_err(|error| {
-                tonic::Status::internal(format!("Blocking task panicked: {error:?}"))
-            })?;
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
         match status {
             Ok(mut status) => {
                 status.status = 0;
@@ -231,10 +199,7 @@ impl NodeWriter for NodeWriterGRPCDriver {
         }
     }
 
-    async fn remove_resource(
-        &self,
-        request: Request<ResourceId>,
-    ) -> Result<Response<OpStatus>, Status> {
+    async fn remove_resource(&self, request: Request<ResourceId>) -> Result<Response<OpStatus>, Status> {
         let span = Span::current();
         let resource = request.into_inner();
         let shard_id = resource.shard_id.clone();
@@ -244,16 +209,12 @@ impl NodeWriter for NodeWriterGRPCDriver {
         let write_task = || {
             run_with_telemetry(info, move || {
                 let shard = obtain_shard(shards, shard_id_clone)?;
-                shard
-                    .remove_resource(&resource)
-                    .and_then(|()| shard.get_opstatus())
+                shard.remove_resource(&resource).and_then(|()| shard.get_opstatus())
             })
         };
         let status = tokio::task::spawn_blocking(write_task)
             .await
-            .map_err(|error| {
-                tonic::Status::internal(format!("Blocking task panicked: {error:?}"))
-            })?;
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
         match status {
             Ok(mut status) => {
                 status.status = 0;
@@ -273,19 +234,12 @@ impl NodeWriter for NodeWriterGRPCDriver {
         }
     }
 
-    async fn add_vector_set(
-        &self,
-        request: Request<NewVectorSetRequest>,
-    ) -> Result<Response<OpStatus>, Status> {
+    async fn add_vector_set(&self, request: Request<NewVectorSetRequest>) -> Result<Response<OpStatus>, Status> {
         let span = Span::current();
         let request = request.into_inner();
         let vectorset_id = match request.id {
             Some(ref vectorset_id) => vectorset_id.clone(),
-            None => {
-                return Err(tonic::Status::invalid_argument(
-                    "Vectorset ID must be provided",
-                ))
-            }
+            None => return Err(tonic::Status::invalid_argument("Vectorset ID must be provided")),
         };
         let shard_id = match vectorset_id.shard {
             Some(ref shard_id) => &shard_id.id,
@@ -298,14 +252,12 @@ impl NodeWriter for NodeWriterGRPCDriver {
         let task = || {
             run_with_telemetry(info, move || {
                 let shard = obtain_shard(shards, shard_id_clone)?;
-                shard
-                    .add_vectorset(&vectorset_id, request.similarity())
-                    .and_then(|()| shard.get_opstatus())
+                shard.add_vectorset(&vectorset_id, request.similarity()).and_then(|()| shard.get_opstatus())
             })
         };
-        let status = tokio::task::spawn_blocking(task).await.map_err(|error| {
-            tonic::Status::internal(format!("Blocking task panicked: {error:?}"))
-        })?;
+        let status = tokio::task::spawn_blocking(task)
+            .await
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
         match status {
             Ok(mut status) => {
                 status.status = 0;
@@ -316,10 +268,7 @@ impl NodeWriter for NodeWriterGRPCDriver {
         }
     }
 
-    async fn remove_vector_set(
-        &self,
-        request: Request<VectorSetId>,
-    ) -> Result<Response<OpStatus>, Status> {
+    async fn remove_vector_set(&self, request: Request<VectorSetId>) -> Result<Response<OpStatus>, Status> {
         let span = Span::current();
         let request = request.into_inner();
         let shard_id = match request.shard {
@@ -332,14 +281,12 @@ impl NodeWriter for NodeWriterGRPCDriver {
         let task = || {
             run_with_telemetry(info, move || {
                 let shard = obtain_shard(shards, shard_id_clone)?;
-                shard
-                    .remove_vectorset(&request)
-                    .and_then(|()| shard.get_opstatus())
+                shard.remove_vectorset(&request).and_then(|()| shard.get_opstatus())
             })
         };
-        let status = tokio::task::spawn_blocking(task).await.map_err(|error| {
-            tonic::Status::internal(format!("Blocking task panicked: {error:?}"))
-        })?;
+        let status = tokio::task::spawn_blocking(task)
+            .await
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
         match status {
             Ok(mut status) => {
                 status.status = 0;
@@ -350,10 +297,7 @@ impl NodeWriter for NodeWriterGRPCDriver {
         }
     }
 
-    async fn list_vector_sets(
-        &self,
-        request: Request<ShardId>,
-    ) -> Result<Response<VectorSetList>, Status> {
+    async fn list_vector_sets(&self, request: Request<ShardId>) -> Result<Response<VectorSetList>, Status> {
         let span = Span::current();
         let shard_id = request.into_inner();
         let shards = Arc::clone(&self.shards);
@@ -363,9 +307,9 @@ impl NodeWriter for NodeWriterGRPCDriver {
             let shard = obtain_shard(shards, shard_id_clone)?;
             run_with_telemetry(info, move || shard.list_vectorsets())
         };
-        let status = tokio::task::spawn_blocking(task).await.map_err(|error| {
-            tonic::Status::internal(format!("Blocking task panicked: {error:?}"))
-        })?;
+        let status = tokio::task::spawn_blocking(task)
+            .await
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
         match status {
             Ok(vectorset) => {
                 let list = VectorSetList {
@@ -378,35 +322,39 @@ impl NodeWriter for NodeWriterGRPCDriver {
         }
     }
 
-    async fn get_metadata(
-        &self,
-        _request: Request<EmptyQuery>,
-    ) -> Result<Response<NodeMetadata>, Status> {
-        let metadata_settings = self.settings.clone();
-        let metadata = crate::node_metadata::NodeMetadata::new(metadata_settings).await;
-        match metadata {
-            Ok(metadata) => Ok(tonic::Response::new(metadata.into())),
-            Err(error) => Err(tonic::Status::internal(error.to_string())),
+    async fn get_metadata(&self, _request: Request<EmptyQuery>) -> Result<Response<NodeMetadata>, Status> {
+        let settings = &self.settings.clone();
+        let mut total_disk = 0;
+        let mut available_disk = 0;
+
+        for disk in sysinfo::Disks::new_with_refreshed_list().into_iter() {
+            total_disk += disk.total_space();
+            available_disk += disk.available_space();
         }
+        Ok(tonic::Response::new(NodeMetadata {
+            shard_count: list_shards(settings.shards_path()).await.len().try_into().unwrap(),
+            node_id: read_host_key(settings.host_key_path()).unwrap().to_string(),
+            primary_node_id: get_primary_node_id(settings.data_path()),
+            available_disk,
+            total_disk,
+            ..Default::default()
+        }))
     }
 
-    async fn gc(
-        &self,
-        request: Request<ShardId>,
-    ) -> Result<Response<GarbageCollectorResponse>, Status> {
+    async fn gc(&self, request: Request<ShardId>) -> Result<Response<GarbageCollectorResponse>, Status> {
         send_analytics_event(AnalyticsEvent::GarbageCollect).await;
         let shard_id = request.into_inner();
         let shards = Arc::clone(&self.shards);
         let shard_id_clone = shard_id.id.clone();
         let span = Span::current();
-        let info = info_span!(parent: &span, "list vector sets");
+        let info = info_span!(parent: &span, "garbage collection");
         let task = || {
             let shard = obtain_shard(shards, shard_id_clone)?;
             run_with_telemetry(info, move || shard.gc())
         };
-        let result = tokio::task::spawn_blocking(task).await.map_err(|error| {
-            tonic::Status::internal(format!("Blocking task panicked: {error:?}"))
-        })?;
+        let result = tokio::task::spawn_blocking(task)
+            .await
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
         match result {
             Ok(status) => Ok(tonic::Response::new(GarbageCollectorResponse {
                 status: garbage_collector_response::Status::from(status) as i32,
@@ -414,4 +362,26 @@ impl NodeWriter for NodeWriterGRPCDriver {
             Err(error) => Err(tonic::Status::internal(error.to_string())),
         }
     }
+
+    async fn merge(&self, request: Request<ShardId>) -> Result<Response<MergeResponse>, Status> {
+        let shard_id = request.into_inner().id;
+        let shards = Arc::clone(&self.shards);
+        let span = info_span!(parent: Span::current(), "merge");
+        let task = || {
+            let shard = obtain_shard(shards, shard_id)?;
+            run_with_telemetry(span, move || shard.merge())
+        };
+        let result = tokio::task::spawn_blocking(task)
+            .await
+            .map_err(|error| tonic::Status::internal(format!("Blocking task panicked: {error:?}")))?;
+
+        match result {
+            Ok(metrics) => Ok(tonic::Response::new(MergeResponse {
+                status: merge_response::MergeStatus::Ok.into(),
+                merged_segments: metrics.merged as u32,
+                remaining_segments: metrics.left as u32,
+            })),
+            Err(error) => Err(tonic::Status::internal(error.to_string())),
+        }
+    }
 }
