@@ -16,31 +16,31 @@
 // You should have received a copy of the GNU Affero General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-use std::collections::HashSet;
-use std::fs::{self, File};
-use std::io::{BufReader, Read};
-use std::path::{Path, PathBuf};
-
 use crossbeam_utils::thread as crossbeam_thread;
+use nucliadb_core::paragraphs::*;
 use nucliadb_core::prelude::*;
 use nucliadb_core::protos;
-use nucliadb_core::protos::shard_created::{
-    DocumentService, ParagraphService, RelationService, VectorService,
-};
+use nucliadb_core::protos::shard_created::{DocumentService, ParagraphService, RelationService, VectorService};
 use nucliadb_core::protos::{
-    DocumentSearchRequest, DocumentSearchResponse, EdgeList, GetShardRequest,
-    ParagraphSearchRequest, ParagraphSearchResponse, RelationPrefixSearchRequest,
-    RelationSearchRequest, RelationSearchResponse, SearchRequest, SearchResponse, Shard, ShardFile,
-    ShardFileChunk, ShardFileList, StreamRequest, SuggestFeatures, SuggestRequest, SuggestResponse,
-    TypeList, VectorSearchRequest, VectorSearchResponse,
+    DocumentSearchRequest, DocumentSearchResponse, EdgeList, GetShardRequest, ParagraphSearchRequest,
+    ParagraphSearchResponse, RelationPrefixSearchRequest, RelationSearchRequest, RelationSearchResponse, SearchRequest,
+    SearchResponse, Shard, ShardFile, ShardFileChunk, ShardFileList, StreamRequest, SuggestFeatures, SuggestRequest,
+    SuggestResponse, TypeList, VectorSearchRequest, VectorSearchResponse,
 };
-use nucliadb_core::query_planner::QueryPlan;
+use nucliadb_core::query_planner;
+use nucliadb_core::relations::*;
+use nucliadb_core::texts::*;
 use nucliadb_core::thread::*;
 use nucliadb_core::tracing::{self, *};
+use nucliadb_core::vectors::*;
 use nucliadb_procs::measure;
 use nucliadb_protos::nodereader::{RelationNodeFilter, RelationPrefixSearchResponse};
 use nucliadb_protos::utils::relation_node::NodeType;
 use nucliadb_relations2::reader::HashedRelationNode;
+use std::collections::HashSet;
+use std::fs::{self, File};
+use std::io::{BufReader, Read};
+use std::path::{Path, PathBuf};
 
 use crate::disk_structure::*;
 use crate::shards::metadata::ShardMetadata;
@@ -321,12 +321,8 @@ impl ShardReader {
     pub fn suggest(&self, request: SuggestRequest) -> NodeResult<SuggestResponse> {
         let span = tracing::Span::current();
 
-        let suggest_paragraphs = request
-            .features
-            .contains(&(SuggestFeatures::Paragraphs as i32));
-        let suggest_entities = request
-            .features
-            .contains(&(SuggestFeatures::Entities as i32));
+        let suggest_paragraphs = request.features.contains(&(SuggestFeatures::Paragraphs as i32));
+        let suggest_entities = request.features.contains(&(SuggestFeatures::Entities as i32));
 
         let paragraphs_reader_service = self.paragraph_reader.clone();
         let relations_reader_service = self.relation_reader.clone();
@@ -340,24 +336,21 @@ impl ShardReader {
 
         let relation_task = suggest_entities.then(|| {
             let relation_task = move || {
-                let requests = prefixes
-                    .par_iter()
-                    .filter(|prefix| prefix.len() >= MIN_VIABLE_PREFIX_SUGGEST)
-                    .cloned()
-                    .map(|prefix| RelationSearchRequest {
-                        prefix: Some(RelationPrefixSearchRequest {
-                            prefix,
-                            node_filters: vec![RelationNodeFilter {
-                                node_type: NodeType::Entity.into(),
-                                ..Default::default()
-                            }],
-                        }),
-                        ..Default::default()
-                    });
+                let requests =
+                    prefixes.par_iter().filter(|prefix| prefix.len() >= MIN_VIABLE_PREFIX_SUGGEST).cloned().map(
+                        |prefix| RelationSearchRequest {
+                            prefix: Some(RelationPrefixSearchRequest {
+                                prefix,
+                                node_filters: vec![RelationNodeFilter {
+                                    node_type: NodeType::Entity.into(),
+                                    ..Default::default()
+                                }],
+                            }),
+                            ..Default::default()
+                        },
+                    );
 
-                let responses = requests
-                    .map(|request| relations_reader_service.search(&request))
-                    .collect::<Vec<_>>();
+                let responses = requests.map(|request| relations_reader_service.search(&request)).collect::<Vec<_>>();
 
                 let entities = responses
                     .into_iter()
@@ -403,7 +396,9 @@ impl ShardReader {
         };
 
         if let Some(entities) = entities {
-            response.entity_results = Some(RelationPrefixSearchResponse { nodes: entities });
+            response.entity_results = Some(RelationPrefixSearchResponse {
+                nodes: entities,
+            });
         }
 
         Ok(response)
@@ -412,17 +407,16 @@ impl ShardReader {
     #[measure(actor = "shard", metric = "request/search")]
     #[tracing::instrument(skip_all)]
     pub fn search(&self, search_request: SearchRequest) -> NodeResult<SearchResponse> {
-        let query_plan = QueryPlan::from(search_request);
+        let query_plan = query_planner::build_query_plan(search_request)?;
 
         let search_id = uuid::Uuid::new_v4().to_string();
         let span = tracing::Span::current();
-        let pre_filter = query_plan.pre_filter;
         let mut index_queries = query_plan.index_queries;
 
         // Apply pre-filtering to the query plan
-        if let Some(pre_filter) = pre_filter {
-            let pre_filtered = self.text_reader.pre_filter(&pre_filter)?;
-            index_queries.apply_pre_filter(pre_filtered);
+        if let Some(prefilter) = &query_plan.prefilter {
+            let prefiltered = self.text_reader.prefilter(prefilter)?;
+            index_queries.apply_prefilter(prefiltered);
         }
 
         // Run the rest of the plan
@@ -436,17 +430,19 @@ impl ShardReader {
 
         let paragraph_task = index_queries.paragraphs_request.map(|mut request| {
             request.id = search_id.clone();
+            let paragraphs_context = &index_queries.paragraphs_context;
             let paragraph_reader_service = self.paragraph_reader.clone();
             let info = info_span!(parent: &span, "paragraph search");
-            let task = move || paragraph_reader_service.search(&request);
+            let task = move || paragraph_reader_service.search(&request, paragraphs_context);
             || run_with_telemetry(info, task)
         });
 
         let vector_task = index_queries.vectors_request.map(|mut request| {
             request.id = search_id.clone();
+            let vectors_context = &index_queries.vectors_context;
             let vector_reader_service = self.vector_reader.clone();
             let info = info_span!(parent: &span, "vector search");
-            let task = move || vector_reader_service.search(&request);
+            let task = move || vector_reader_service.search(&request, vectors_context);
             || run_with_telemetry(info, task)
         });
 
@@ -497,27 +493,18 @@ impl ShardReader {
     #[tracing::instrument(skip_all)]
     pub fn document_iterator(&self, request: StreamRequest) -> NodeResult<DocumentIterator> {
         let span = tracing::Span::current();
-        run_with_telemetry(info_span!(parent: &span, "field iteration"), || {
-            self.text_reader.iterator(&request)
-        })
+        run_with_telemetry(info_span!(parent: &span, "field iteration"), || self.text_reader.iterator(&request))
     }
 
     #[tracing::instrument(skip_all)]
-    pub fn download_file_iterator(
-        &self,
-        relative_path: String,
-    ) -> NodeResult<ShardFileChunkIterator> {
+    pub fn download_file_iterator(&self, relative_path: String) -> NodeResult<ShardFileChunkIterator> {
         let span = tracing::Span::current();
         run_with_telemetry(info_span!(parent: &span, "download file iteration"), || {
             ShardFileChunkIterator::new(self.root_path.join(relative_path), CHUNK_SIZE)
         })
     }
 
-    fn visit_directories(
-        &self,
-        path: PathBuf,
-        to_visit: &mut Vec<PathBuf>,
-    ) -> NodeResult<Vec<ShardFile>> {
+    fn visit_directories(&self, path: PathBuf, to_visit: &mut Vec<PathBuf>) -> NodeResult<Vec<ShardFile>> {
         let dir = fs::read_dir(path)?;
         let mut files = Vec::new();
 
@@ -549,25 +536,21 @@ impl ShardReader {
             files.append(&mut files_found);
         }
 
-        Ok(ShardFileList { files })
-    }
-
-    #[tracing::instrument(skip_all)]
-    pub fn paragraph_search(
-        &self,
-        search_request: ParagraphSearchRequest,
-    ) -> NodeResult<ParagraphSearchResponse> {
-        let span = tracing::Span::current();
-        run_with_telemetry(info_span!(parent: &span, "paragraph reader search"), || {
-            self.paragraph_reader.search(&search_request)
+        Ok(ShardFileList {
+            files,
         })
     }
 
     #[tracing::instrument(skip_all)]
-    pub fn document_search(
-        &self,
-        search_request: DocumentSearchRequest,
-    ) -> NodeResult<DocumentSearchResponse> {
+    pub fn paragraph_search(&self, search_request: ParagraphSearchRequest) -> NodeResult<ParagraphSearchResponse> {
+        let span = tracing::Span::current();
+        run_with_telemetry(info_span!(parent: &span, "paragraph reader search"), || {
+            self.paragraph_reader.search(&search_request, &ParagraphsContext::default())
+        })
+    }
+
+    #[tracing::instrument(skip_all)]
+    pub fn document_search(&self, search_request: DocumentSearchRequest) -> NodeResult<DocumentSearchResponse> {
         let span = tracing::Span::current();
 
         run_with_telemetry(info_span!(parent: &span, "field reader search"), || {
@@ -576,21 +559,15 @@ impl ShardReader {
     }
 
     #[tracing::instrument(skip_all)]
-    pub fn vector_search(
-        &self,
-        search_request: VectorSearchRequest,
-    ) -> NodeResult<VectorSearchResponse> {
+    pub fn vector_search(&self, search_request: VectorSearchRequest) -> NodeResult<VectorSearchResponse> {
         let span = tracing::Span::current();
 
         run_with_telemetry(info_span!(parent: &span, "vector reader search"), || {
-            self.vector_reader.search(&search_request)
+            self.vector_reader.search(&search_request, &VectorsContext::default())
         })
     }
     #[tracing::instrument(skip_all)]
-    pub fn relation_search(
-        &self,
-        search_request: RelationSearchRequest,
-    ) -> NodeResult<RelationSearchResponse> {
+    pub fn relation_search(&self, search_request: RelationSearchRequest) -> NodeResult<RelationSearchResponse> {
         let span = tracing::Span::current();
 
         run_with_telemetry(info_span!(parent: &span, "relation reader search"), || {
