@@ -20,12 +20,14 @@ use std::collections::HashMap;
 use std::path::PathBuf;
 use std::sync::{Arc, Mutex, MutexGuard};
 
+use nucliadb_core::paragraphs::*;
 use nucliadb_core::prelude::*;
-use nucliadb_core::protos::shard_created::{
-    DocumentService, ParagraphService, RelationService, VectorService,
-};
+use nucliadb_core::protos::shard_created::{DocumentService, ParagraphService, RelationService, VectorService};
 use nucliadb_core::protos::{OpStatus, Resource, ResourceId, VectorSetId, VectorSimilarity};
+use nucliadb_core::relations::*;
+use nucliadb_core::texts::*;
 use nucliadb_core::tracing::{self, *};
+use nucliadb_core::vectors::*;
 use nucliadb_core::{thread, IndexFiles};
 use nucliadb_procs::measure;
 use nucliadb_vectors::VectorErr;
@@ -63,10 +65,7 @@ impl ShardWriter {
         vsc: VectorConfig,
         rsc: RelationConfig,
     ) -> NodeResult<ShardWriter> {
-        let versions = Versions::load_or_create(
-            &metadata.shard_path().join(VERSION_FILE),
-            metadata.channel(),
-        )?;
+        let versions = Versions::load_or_create(&metadata.shard_path().join(VERSION_FILE), metadata.channel())?;
         let text_task = || Some(versions.get_texts_writer(&tsc));
         let paragraph_task = || Some(versions.get_paragraphs_writer(&psc));
         let vector_task = || Some(versions.get_vectors_writer(&vsc));
@@ -149,36 +148,6 @@ impl ShardWriter {
             i => panic!("Unknown relation version {i}"),
         }
     }
-    pub fn clean_and_create(metadata: Arc<ShardMetadata>) -> NodeResult<ShardWriter> {
-        let path = metadata.shard_path();
-        std::fs::remove_dir_all(path.clone())?;
-        std::fs::create_dir(path.clone())?;
-        let tsc = TextConfig {
-            path: path.clone().join(TEXTS_DIR),
-        };
-
-        let psc = ParagraphConfig {
-            path: path.clone().join(PARAGRAPHS_DIR),
-        };
-
-        let channel = metadata.channel();
-
-        let vsc = VectorConfig {
-            similarity: Some(metadata.similarity()),
-            path: path.clone().join(VECTORS_DIR),
-            vectorset: path.clone().join(VECTORSET_DIR),
-            channel,
-        };
-        let rsc = RelationConfig {
-            path: path.clone().join(RELATIONS_DIR),
-            channel,
-        };
-        let shard_metadata = Arc::clone(&metadata);
-        let sw = ShardWriter::initialize(shard_metadata, tsc, psc, vsc, rsc)?;
-        metadata.new_generation_id();
-
-        Ok(sw)
-    }
 
     #[measure(actor = "shard", metric = "new")]
     pub fn new(metadata: Arc<ShardMetadata>) -> NodeResult<ShardWriter> {
@@ -384,21 +353,15 @@ impl ShardWriter {
         let vectors = self.vector_writer.clone();
         let texts = self.text_writer.clone();
 
-        let count_fields = || {
-            run_with_telemetry(info_span!(parent: &span, "field count"), move || {
-                text_read(&texts).count()
-            })
-        };
+        let count_fields =
+            || run_with_telemetry(info_span!(parent: &span, "field count"), move || text_read(&texts).count());
         let count_paragraphs = || {
             run_with_telemetry(info_span!(parent: &span, "paragraph count"), move || {
                 paragraph_read(&paragraphs).count()
             })
         };
-        let count_vectors = || {
-            run_with_telemetry(info_span!(parent: &span, "vector count"), move || {
-                vector_read(&vectors).count()
-            })
-        };
+        let count_vectors =
+            || run_with_telemetry(info_span!(parent: &span, "vector count"), move || vector_read(&vectors).count());
 
         let mut field_count = Ok(0);
         let mut paragraph_count = Ok(0);
@@ -426,11 +389,7 @@ impl ShardWriter {
     }
 
     #[tracing::instrument(skip_all)]
-    pub fn add_vectorset(
-        &self,
-        setid: &VectorSetId,
-        similarity: VectorSimilarity,
-    ) -> NodeResult<()> {
+    pub fn add_vectorset(&self, setid: &VectorSetId, similarity: VectorSimilarity) -> NodeResult<()> {
         let mut writer = vector_write(&self.vector_writer);
         writer.add_vectorset(setid, similarity)?;
 
@@ -477,6 +436,14 @@ impl ShardWriter {
         }
     }
 
+    #[tracing::instrument(skip_all)]
+    pub fn merge(&self) -> NodeResult<MergeMetrics> {
+        let result = vector_write(&self.vector_writer).merge();
+        self.metadata.new_generation_id();
+
+        result
+    }
+
     pub async fn block_shard(&self) -> BlockingToken {
         let mutex_guard = self.write_lock.lock().expect("Poisoned write lock");
         BlockingToken(mutex_guard)
@@ -485,18 +452,10 @@ impl ShardWriter {
     pub fn get_shard_segments(&self) -> NodeResult<HashMap<String, Vec<String>>> {
         let mut segments = HashMap::new();
 
-        segments.insert(
-            "paragraph".to_string(),
-            paragraph_read(&self.paragraph_writer).get_segment_ids()?,
-        );
-        segments.insert(
-            "text".to_string(),
-            text_read(&self.text_writer).get_segment_ids()?,
-        );
-        segments.insert(
-            "vector".to_string(),
-            vector_read(&self.vector_writer).get_segment_ids()?,
-        );
+        segments.insert("paragraph".to_string(), paragraph_read(&self.paragraph_writer).get_segment_ids()?);
+        segments.insert("text".to_string(), text_read(&self.text_writer).get_segment_ids()?);
+        segments.insert("vector".to_string(), vector_read(&self.vector_writer).get_segment_ids()?);
+        segments.insert("relation".to_string(), relation_read(&self.relation_writer).get_segment_ids()?);
 
         Ok(segments)
     }
@@ -509,8 +468,8 @@ impl ShardWriter {
         let _lock = self.write_lock.lock().expect("Poisoned write lock"); // need to make sure more writes don't happen while we are reading
         let paragraph_files = paragraph_read(&self.paragraph_writer)
             .get_index_files(ignored_segement_ids.get("paragraph").unwrap_or(&Vec::new()))?;
-        let text_files = text_read(&self.text_writer)
-            .get_index_files(ignored_segement_ids.get("text").unwrap_or(&Vec::new()))?;
+        let text_files =
+            text_read(&self.text_writer).get_index_files(ignored_segement_ids.get("text").unwrap_or(&Vec::new()))?;
         let vector_files = vector_read(&self.vector_writer)
             .get_index_files(ignored_segement_ids.get("vector").unwrap_or(&Vec::new()))?;
         let relation_files = relation_read(&self.relation_writer)
@@ -531,12 +490,8 @@ pub enum GarbageCollectorStatus {
 impl From<GarbageCollectorStatus> for nucliadb_core::protos::garbage_collector_response::Status {
     fn from(value: GarbageCollectorStatus) -> Self {
         match value {
-            GarbageCollectorStatus::GarbageCollected => {
-                nucliadb_core::protos::garbage_collector_response::Status::Ok
-            }
-            GarbageCollectorStatus::TryLater => {
-                nucliadb_core::protos::garbage_collector_response::Status::TryLater
-            }
+            GarbageCollectorStatus::GarbageCollected => nucliadb_core::protos::garbage_collector_response::Status::Ok,
+            GarbageCollectorStatus::TryLater => nucliadb_core::protos::garbage_collector_response::Status::TryLater,
         }
     }
 }
