@@ -21,12 +21,10 @@
 use std::fmt::Debug;
 use std::time::Instant;
 
+use nucliadb_core::paragraphs::*;
 use nucliadb_core::prelude::*;
 use nucliadb_core::protos::order_by::{OrderField, OrderType};
-use nucliadb_core::protos::{
-    OrderBy, ParagraphItem, ParagraphSearchRequest, ParagraphSearchResponse, StreamRequest,
-    SuggestRequest,
-};
+use nucliadb_core::protos::{OrderBy, ParagraphItem, StreamRequest, SuggestRequest};
 use nucliadb_core::tracing::{self, *};
 use nucliadb_procs::measure;
 use search_query::{search_query, suggest_query};
@@ -51,10 +49,7 @@ pub struct ParagraphReaderService {
 
 impl Debug for ParagraphReaderService {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("TextService")
-            .field("index", &self.index)
-            .field("schema", &self.schema)
-            .finish()
+        f.debug_struct("TextService").field("index", &self.index).field("schema", &self.schema).finish()
     }
 }
 
@@ -69,7 +64,7 @@ impl ParagraphReader for ParagraphReaderService {
 
     #[measure(actor = "paragraphs", metric = "suggest")]
     #[tracing::instrument(skip_all)]
-    fn suggest(&self, request: &SuggestRequest) -> NodeResult<Self::Response> {
+    fn suggest(&self, request: &SuggestRequest) -> NodeResult<ProtosResponse> {
         let time = Instant::now();
         let id = Some(&request.shard);
 
@@ -78,8 +73,7 @@ impl ParagraphReader for ParagraphReaderService {
 
         let parser = QueryParser::for_index(&self.index, vec![self.schema.text]);
         let text = self.adapt_text(&parser, &request.body);
-        let (original, termc, fuzzied) =
-            suggest_query(&parser, &text, request, &self.schema, FUZZY_DISTANCE);
+        let (original, termc, fuzzied) = suggest_query(&parser, &text, request, &self.schema, FUZZY_DISTANCE);
         let v = time.elapsed().as_millis();
         debug!("{id:?} - Creating query: ends at {v} ms");
 
@@ -107,7 +101,7 @@ impl ParagraphReader for ParagraphReaderService {
         let v = time.elapsed().as_millis();
         debug!("{id:?} - Ending at: {v} ms");
 
-        Ok(ParagraphSearchResponse::from(SearchBm25Response {
+        Ok(ProtosResponse::from(SearchBm25Response {
             total: results.len(),
             top_docs: results,
             facets_count: None,
@@ -133,15 +127,10 @@ impl ParagraphReader for ParagraphReaderService {
         };
         Ok(ParagraphIterator::new(producer.flatten()))
     }
-}
-
-impl ReaderChild for ParagraphReaderService {
-    type Request = ParagraphSearchRequest;
-    type Response = ParagraphSearchResponse;
 
     #[measure(actor = "paragraphs", metric = "search")]
     #[tracing::instrument(skip_all)]
-    fn search(&self, request: &Self::Request) -> NodeResult<Self::Response> {
+    fn search(&self, request: &ProtosRequest, context: &ParagraphsContext) -> NodeResult<ProtosResponse> {
         let time = Instant::now();
         let id = Some(&request.id);
 
@@ -166,18 +155,15 @@ impl ReaderChild for ParagraphReaderService {
         let v = time.elapsed().as_millis();
         debug!("{id:?} - Searching: starts at {v} ms");
 
-        let advanced = request
-            .advanced_query
-            .as_ref()
-            .map(|query| parser.parse_query(query))
-            .transpose()?;
-        let (original, termc, fuzzied) = search_query(
+        let advanced = request.advanced_query.as_ref().map(|query| parser.parse_query(query)).transpose()?;
+        #[rustfmt::skip] let (original, termc, fuzzied) = search_query(
             &parser,
             &text,
             request,
             &self.schema,
+            context,
             FUZZY_DISTANCE,
-            advanced,
+            advanced
         );
         let searcher = Searcher {
             request,
@@ -227,10 +213,7 @@ impl ReaderChild for ParagraphReaderService {
         let mut keys = vec![];
         let searcher = self.reader.searcher();
         for addr in searcher.search(&AllQuery, &DocSetCollector)? {
-            let Some(key) = searcher
-                .doc(addr)?
-                .get_first(self.schema.uuid)
-                .and_then(|i| i.as_text().map(String::from))
+            let Some(key) = searcher.doc(addr)?.get_first(self.schema.uuid).and_then(|i| i.as_text().map(String::from))
             else {
                 continue;
             };
@@ -249,10 +232,7 @@ impl ParagraphReaderService {
         }
         let paragraph_schema = ParagraphSchema::default();
         let index = Index::open_in_dir(&config.path)?;
-        let reader = index
-            .reader_builder()
-            .reload_policy(ReloadPolicy::OnCommit)
-            .try_into()?;
+        let reader = index.reader_builder().reload_policy(ReloadPolicy::OnCommit).try_into()?;
         Ok(ParagraphReaderService {
             index,
             reader,
@@ -314,7 +294,10 @@ impl Iterator for BatchProducer {
                 .map(|x| x.to_path_string())
                 .filter(|x| x.starts_with("/l/"))
                 .collect::<Vec<_>>();
-            items.push(ParagraphItem { id, labels });
+            items.push(ParagraphItem {
+                id,
+                labels,
+            });
         }
         self.offset += Self::BATCH;
         let v = time.elapsed().as_millis();
@@ -325,7 +308,7 @@ impl Iterator for BatchProducer {
 }
 
 struct Searcher<'a> {
-    request: &'a ParagraphSearchRequest,
+    request: &'a ProtosRequest,
     results: usize,
     offset: usize,
     facets: &'a [String],
@@ -348,34 +331,30 @@ impl<'a> Searcher<'a> {
             OrderType::Desc => |t: u64| t,
             OrderType::Asc => |t: u64| u64::MAX - t,
         };
-        TopDocs::with_limit(limit).and_offset(offset).custom_score(
-            move |segment_reader: &SegmentReader| {
-                let reader = match order.sort_by() {
-                    OrderField::Created => segment_reader.fast_fields().date(created).unwrap(),
-                    OrderField::Modified => segment_reader.fast_fields().date(modified).unwrap(),
-                };
-                move |doc: DocId| sorter(reader.get(doc).to_u64())
-            },
-        )
+        TopDocs::with_limit(limit).and_offset(offset).custom_score(move |segment_reader: &SegmentReader| {
+            let reader = match order.sort_by() {
+                OrderField::Created => segment_reader.fast_fields().date(created).unwrap(),
+                OrderField::Modified => segment_reader.fast_fields().date(modified).unwrap(),
+            };
+            move |doc: DocId| sorter(reader.get(doc).to_u64())
+        })
     }
     fn do_search(
         &self,
         termc: SharedTermC,
         query: Box<dyn Query>,
         service: &ParagraphReaderService,
-    ) -> NodeResult<ParagraphSearchResponse> {
+    ) -> NodeResult<ProtosResponse> {
         let searcher = service.reader.searcher();
-        let facet_collector = self.facets.iter().fold(
-            FacetCollector::for_field(service.schema.facets),
-            |mut collector, facet| {
+        let facet_collector =
+            self.facets.iter().fold(FacetCollector::for_field(service.schema.facets), |mut collector, facet| {
                 collector.add_facet(Facet::from(facet));
                 collector
-            },
-        );
+            });
         if self.only_faceted {
             // No query search, just facets
             let facets_count = searcher.search(&query, &facet_collector).unwrap();
-            Ok(ParagraphSearchResponse::from(SearchFacetsResponse {
+            Ok(ProtosResponse::from(SearchFacetsResponse {
                 text_service: service,
                 facets_count: Some(facets_count),
                 facets: self.facets.to_vec(),
@@ -385,11 +364,10 @@ impl<'a> Searcher<'a> {
             let extra_result = self.results + 1;
             match self.request.order.clone() {
                 Some(order) => {
-                    let custom_collector =
-                        self.custom_order_collector(order, extra_result, self.offset);
+                    let custom_collector = self.custom_order_collector(order, extra_result, self.offset);
                     let collector = &(Count, custom_collector);
                     let (total, top_docs) = searcher.search(&query, collector)?;
-                    Ok(ParagraphSearchResponse::from(SearchIntResponse {
+                    Ok(ProtosResponse::from(SearchIntResponse {
                         total,
                         facets_count: None,
                         facets: self.facets.to_vec(),
@@ -403,11 +381,10 @@ impl<'a> Searcher<'a> {
                     }))
                 }
                 None => {
-                    let topdocs_collector =
-                        TopDocs::with_limit(extra_result).and_offset(self.offset);
+                    let topdocs_collector = TopDocs::with_limit(extra_result).and_offset(self.offset);
                     let collector = &(Count, topdocs_collector);
                     let (total, top_docs) = searcher.search(&query, collector)?;
-                    Ok(ParagraphSearchResponse::from(SearchBm25Response {
+                    Ok(ProtosResponse::from(SearchBm25Response {
                         total,
                         facets_count: None,
                         facets: self.facets.to_vec(),
@@ -426,11 +403,10 @@ impl<'a> Searcher<'a> {
 
             match self.request.order.clone() {
                 Some(order) => {
-                    let custom_collector =
-                        self.custom_order_collector(order, extra_result, self.offset);
+                    let custom_collector = self.custom_order_collector(order, extra_result, self.offset);
                     let collector = &(Count, facet_collector, custom_collector);
                     let (total, facets_count, top_docs) = searcher.search(&query, collector)?;
-                    Ok(ParagraphSearchResponse::from(SearchIntResponse {
+                    Ok(ProtosResponse::from(SearchIntResponse {
                         total,
                         top_docs,
                         facets_count: Some(facets_count),
@@ -444,11 +420,10 @@ impl<'a> Searcher<'a> {
                     }))
                 }
                 None => {
-                    let topdocs_collector =
-                        TopDocs::with_limit(extra_result).and_offset(self.offset);
+                    let topdocs_collector = TopDocs::with_limit(extra_result).and_offset(self.offset);
                     let collector = &(Count, facet_collector, topdocs_collector);
                     let (total, facets_count, top_docs) = searcher.search(&query, collector)?;
-                    Ok(ParagraphSearchResponse::from(SearchBm25Response {
+                    Ok(ProtosResponse::from(SearchBm25Response {
                         total,
                         top_docs,
                         facets_count: Some(facets_count),
@@ -469,16 +444,16 @@ impl<'a> Searcher<'a> {
 #[cfg(test)]
 mod tests {
 
-    use std::collections::HashMap;
-    use std::time::SystemTime;
-
     use nucliadb_core::protos::prost_types::Timestamp;
     use nucliadb_core::protos::resource::ResourceStatus;
     use nucliadb_core::protos::{
-        Faceted, Filter, IndexMetadata, IndexParagraph, IndexParagraphs, OrderBy, Resource,
-        ResourceId, TextInformation, Timestamps,
+        Faceted, IndexMetadata, IndexParagraph, IndexParagraphs, OrderBy, Resource, ResourceId, TextInformation,
+        Timestamps,
     };
+    use nucliadb_core::query_language::{self, BooleanExpression};
     use nucliadb_core::NodeResult;
+    use std::collections::HashMap;
+    use std::time::SystemTime;
     use tantivy::collector::Count;
     use tantivy::query::AllQuery;
     use tempfile::TempDir;
@@ -535,23 +510,13 @@ mod tests {
             end: (DOC1_P1.len() + DOC1_P2.len()) as i32,
             sentences: HashMap::new(),
             field: "body".to_string(),
-            labels: vec![
-                "/tantivy".to_string(),
-                "/test".to_string(),
-                "/label1".to_string(),
-            ],
+            labels: vec!["/tantivy".to_string(), "/test".to_string(), "/label1".to_string()],
             index: 1,
             split: "".to_string(),
             repeated_in_field: false,
             metadata: None,
         };
-        let p2_uuid = format!(
-            "{}/{}/{}-{}",
-            UUID,
-            "body",
-            DOC1_P1.len(),
-            DOC1_P1.len() + DOC1_P2.len()
-        );
+        let p2_uuid = format!("{}/{}/{}-{}", UUID, "body", DOC1_P1.len(), DOC1_P1.len() + DOC1_P2.len());
 
         let p3 = IndexParagraph {
             start: (DOC1_P1.len() + DOC1_P2.len()) as i32,
@@ -573,9 +538,7 @@ mod tests {
         );
 
         let body_paragraphs = IndexParagraphs {
-            paragraphs: [(p1_uuid, p1), (p2_uuid, p2), (p3_uuid, p3)]
-                .into_iter()
-                .collect(),
+            paragraphs: [(p1_uuid, p1), (p2_uuid, p2), (p3_uuid, p3)].into_iter().collect(),
         };
 
         let p4 = IndexParagraph {
@@ -595,12 +558,8 @@ mod tests {
             paragraphs: [(p4_uuid, p4)].into_iter().collect(),
         };
 
-        let paragraphs = [
-            ("body".to_string(), body_paragraphs),
-            ("title".to_string(), title_paragraphs),
-        ]
-        .into_iter()
-        .collect();
+        let paragraphs =
+            [("body".to_string(), body_paragraphs), ("title".to_string(), title_paragraphs)].into_iter().collect();
 
         Resource {
             resource: Some(resource_id),
@@ -625,19 +584,20 @@ mod tests {
         let psc = ParagraphConfig {
             path: dir.path().join("paragraphs"),
         };
-        let seconds = SystemTime::now()
-            .duration_since(SystemTime::UNIX_EPOCH)
-            .map(|t| t.as_secs() as i64)
-            .unwrap();
-        let timestamp = Timestamp { seconds, nanos: 0 };
+        let seconds = SystemTime::now().duration_since(SystemTime::UNIX_EPOCH).map(|t| t.as_secs() as i64).unwrap();
+        let timestamp = Timestamp {
+            seconds,
+            nanos: 0,
+        };
 
         let mut paragraph_writer_service = ParagraphWriterService::start(&psc).unwrap();
         let resource1 = create_resource("shard1".to_string(), timestamp);
         let _ = paragraph_writer_service.set_resource(&resource1);
         let paragraph_reader_service = ParagraphReaderService::start(&psc).unwrap();
+        let context = ParagraphsContext::default();
 
         // Search on all paragraphs faceted
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "".to_string(),
@@ -652,11 +612,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &context).unwrap();
         assert_eq!(result.total, 4);
         assert_eq!(result.results.len(), 4);
 
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "".to_string(),
@@ -671,7 +631,7 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &context).unwrap();
         assert!(result.results.is_empty());
         assert_eq!(result.total, 4);
 
@@ -679,16 +639,17 @@ mod tests {
     }
 
     #[test]
-    fn test_new_paragraph() -> NodeResult<()> {
+    fn test_filtered_search() -> NodeResult<()> {
+        const UUID: &str = "f56c58ac-b4f9-4d61-a077-ffccaadd0001";
         let dir = TempDir::new().unwrap();
         let psc = ParagraphConfig {
             path: dir.path().join("paragraphs"),
         };
-        let seconds = SystemTime::now()
-            .duration_since(SystemTime::UNIX_EPOCH)
-            .map(|t| t.as_secs() as i64)
-            .unwrap();
-        let timestamp = Timestamp { seconds, nanos: 0 };
+        let seconds = SystemTime::now().duration_since(SystemTime::UNIX_EPOCH).map(|t| t.as_secs() as i64).unwrap();
+        let timestamp = Timestamp {
+            seconds,
+            nanos: 0,
+        };
 
         let mut paragraph_writer_service = ParagraphWriterService::start(&psc).unwrap();
         let resource1 = create_resource("shard1".to_string(), timestamp);
@@ -698,40 +659,12 @@ mod tests {
 
         let reader = paragraph_writer_service.index.reader()?;
         let searcher = reader.searcher();
-
+        let mut context = ParagraphsContext::default();
         let (_top_docs, count) = searcher.search(&AllQuery, &(TopDocs::with_limit(10), Count))?;
         assert_eq!(count, 4);
 
-        const UUID: &str = "f56c58ac-b4f9-4d61-a077-ffccaadd0001";
-
-        // Testing filtering one filter from resource, one from field and one from paragraph
-
-        let filter = Filter {
-            field_labels: vec![
-                "/l/mylabel_resource".to_string(),
-                "/c/ool".to_string(),
-                "/e/mylabel".to_string(),
-            ],
-            paragraph_labels: vec![],
-        };
-
-        let faceted = Faceted {
-            labels: vec![
-                "".to_string(),
-                "/l".to_string(),
-                "/e".to_string(),
-                "/c".to_string(),
-            ],
-        };
-
-        let order = OrderBy {
-            sort_by: OrderField::Created as i32,
-            r#type: 0,
-            ..Default::default()
-        };
-
-        // Search on all paragraphs faceted
-        let search = ParagraphSearchRequest {
+        // Only one paragraph  matches
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "".to_string(),
@@ -746,16 +679,76 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
-        assert_eq!(result.total, 4);
+        context.filtering_formula = Some(BooleanExpression::Literal("/tantivy".to_string()));
+        let result = paragraph_reader_service.search(&search, &context).unwrap();
+        assert_eq!(result.total, 1);
 
-        // Search on all paragraphs
-        let search = ParagraphSearchRequest {
+        // Two matches due to OR
+        let expression = query_language::BooleanOperation {
+            operator: query_language::Operator::Or,
+            operands: vec![
+                BooleanExpression::Literal("/tantivy".to_string()),
+                BooleanExpression::Literal("/label2".to_string()),
+            ],
+        };
+        context.filtering_formula = Some(BooleanExpression::Operation(expression));
+        let result = paragraph_reader_service.search(&search, &context).unwrap();
+        assert_eq!(result.total, 2);
+
+        // No matches due to AND
+        let expression = query_language::BooleanOperation {
+            operator: query_language::Operator::And,
+            operands: vec![
+                BooleanExpression::Literal("/tantivy".to_string()),
+                BooleanExpression::Literal("/label2".to_string()),
+            ],
+        };
+        context.filtering_formula = Some(BooleanExpression::Operation(expression));
+        let result = paragraph_reader_service.search(&search, &context).unwrap();
+        assert_eq!(result.total, 0);
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_new_paragraph() -> NodeResult<()> {
+        const UUID: &str = "f56c58ac-b4f9-4d61-a077-ffccaadd0001";
+        let dir = TempDir::new().unwrap();
+        let psc = ParagraphConfig {
+            path: dir.path().join("paragraphs"),
+        };
+        let seconds = SystemTime::now().duration_since(SystemTime::UNIX_EPOCH).map(|t| t.as_secs() as i64).unwrap();
+        let timestamp = Timestamp {
+            seconds,
+            nanos: 0,
+        };
+        let mut paragraph_writer_service = ParagraphWriterService::start(&psc).unwrap();
+        let resource1 = create_resource("shard1".to_string(), timestamp);
+        let _ = paragraph_writer_service.set_resource(&resource1);
+        let paragraph_reader_service = ParagraphReaderService::start(&psc).unwrap();
+        let reader = paragraph_writer_service.index.reader()?;
+        let searcher = reader.searcher();
+        let empty_context = ParagraphsContext::default();
+        let (_top_docs, count) = searcher.search(&AllQuery, &(TopDocs::with_limit(10), Count))?;
+        assert_eq!(count, 4);
+
+        let faceted = Faceted {
+            labels: vec!["".to_string(), "/l".to_string(), "/e".to_string(), "/c".to_string()],
+        };
+
+        let order = OrderBy {
+            sort_by: OrderField::Created as i32,
+            r#type: 0,
+            ..Default::default()
+        };
+
+        // Search on all paragraphs faceted
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "".to_string(),
-            fields: vec![],
-            filter: Some(filter.clone()),
+            fields: vec!["body".to_string(), "title".to_string()],
+            filter: None,
             faceted: None,
             order: None,
             page_number: 0,
@@ -765,11 +758,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
-        assert_eq!(result.total, 1);
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
+        assert_eq!(result.total, 4);
 
         // Search on all paragraphs without fields
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "".to_string(),
@@ -784,11 +777,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 4);
 
         // Search on all paragraphs in resource with typo
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "shoupd enaugh".to_string(),
@@ -803,11 +796,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 1);
 
         // Search on all paragraphs in resource with typo
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: UUID.to_string(),
             body: "\"should\" enaugh".to_string(),
@@ -822,11 +815,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 1);
 
         // Search typo on all paragraph
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: "".to_string(),
             body: "shoupd enaugh".to_string(),
@@ -841,11 +834,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 1);
 
         // Search with invalid and unbalanced grammar
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: "".to_string(),
             body: "shoupd + enaugh\"".to_string(),
@@ -860,12 +853,12 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.query, "\"shoupd + enaugh\"");
         assert_eq!(result.total, 0);
 
         // Search with invalid grammar
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: "".to_string(),
             body: "shoupd + enaugh".to_string(),
@@ -880,12 +873,12 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.query, "\"shoupd + enaugh\"");
         assert_eq!(result.total, 0);
 
         // Empty search
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: "".to_string(),
             body: "".to_string(),
@@ -900,11 +893,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 4);
 
         // Search filter all paragraphs
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: "".to_string(),
             body: "this is the".to_string(),
@@ -919,28 +912,11 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 3);
-        let search = ParagraphSearchRequest {
-            id: "shard1".to_string(),
-            uuid: "".to_string(),
-            body: "this is the".to_string(),
-            fields: vec![],
-            filter: Some(filter),
-            faceted: Some(faceted),
-            order: None, // Some(order),
-            page_number: 0,
-            result_per_page: 20,
-            timestamps: None,
-            with_duplicates: false,
-            only_faceted: false,
-            ..Default::default()
-        };
-        let result = paragraph_reader_service.search(&search).unwrap();
-        assert_eq!(result.total, 1);
 
         // Search typo on all paragraph
-        let search = ParagraphSearchRequest {
+        let search = ProtosRequest {
             id: "shard1".to_string(),
             uuid: "".to_string(),
             body: "\"shoupd\"".to_string(),
@@ -955,7 +931,7 @@ mod tests {
             only_faceted: false,
             ..Default::default()
         };
-        let result = paragraph_reader_service.search(&search).unwrap();
+        let result = paragraph_reader_service.search(&search, &empty_context).unwrap();
         assert_eq!(result.total, 0);
 
         let request = StreamRequest {
@@ -989,15 +965,11 @@ mod tests {
 
         let reader = paragraph_writer_service.index.reader()?;
         let searcher = reader.searcher();
-
         let (_top_docs, count) = searcher.search(&AllQuery, &(TopDocs::with_limit(10), Count))?;
         assert_eq!(count, 4);
 
-        fn do_search(
-            paragraph_reader_service: &ParagraphReaderService,
-            timestamps: Timestamps,
-        ) -> i32 {
-            let search = ParagraphSearchRequest {
+        fn do_search(paragraph_reader_service: &ParagraphReaderService, timestamps: Timestamps) -> i32 {
+            let search = ProtosRequest {
                 id: "shard1".to_string(),
                 uuid: "".to_string(),
                 body: "this is the".to_string(),
@@ -1012,7 +984,8 @@ mod tests {
                 only_faceted: false,
                 ..Default::default()
             };
-            let result = paragraph_reader_service.search(&search).unwrap();
+            let context = ParagraphsContext::default();
+            let result = paragraph_reader_service.search(&search, &context).unwrap();
             result.total
         }
 
