@@ -500,7 +500,7 @@ pub mod notification {
         Deleted = 3,
     }
 }
-//// The member information.
+/// The member information.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Member {
     //// Member ID.　A string of the UUID.
@@ -629,11 +629,6 @@ pub struct ResourceIdResponse {
     pub uuid: ::prost::alloc::string::String,
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct ExportRequest {
-    #[prost(string, tag="1")]
-    pub kbid: ::prost::alloc::string::String,
-}
-#[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SetVectorsRequest {
     #[prost(message, optional, tag="1")]
     pub vectors: ::core::option::Option<super::utils::VectorObject>,
@@ -713,20 +708,6 @@ pub struct GetSynonymsResponse {
     #[prost(message, optional, tag="2")]
     pub synonyms: ::core::option::Option<super::knowledgebox::Synonyms>,
 }
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct SetKbConfigurationRequest {
-    #[prost(message, optional, tag="1")]
-    pub kb: ::core::option::Option<super::knowledgebox::KnowledgeBoxId>,
-    #[prost(message, optional, tag="2")]
-    pub config: ::core::option::Option<super::knowledgebox::KbConfiguration>,
-}
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct GetConfigurationResponse {
-    #[prost(message, optional, tag="1")]
-    pub status: ::core::option::Option<OpStatusWriter>,
-    #[prost(message, optional, tag="2")]
-    pub config: ::core::option::Option<super::knowledgebox::KbConfiguration>,
-}
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
 #[repr(i32)]
 pub enum NotificationSource {
