@@ -24,10 +24,10 @@
 use std::collections::HashMap;
 use std::time::SystemTime;
 
-use nucliadb_core::prelude::*;
 use nucliadb_core::protos;
 use nucliadb_core::protos::prost_types::Timestamp;
 use nucliadb_core::protos::{Resource, ResourceId};
+use nucliadb_core::texts::*;
 use nucliadb_texts::reader::TextReaderService;
 use nucliadb_texts::writer::TextWriterService;
 use tempfile::TempDir;
@@ -51,9 +51,7 @@ pub fn create_resource(shard_id: String) -> Resource {
         uuid: "f56c58ac-b4f9-4d61-a077-ffccaadd0001".to_string(),
     };
 
-    let now = SystemTime::now()
-        .duration_since(SystemTime::UNIX_EPOCH)
-        .unwrap();
+    let now = SystemTime::now().duration_since(SystemTime::UNIX_EPOCH).unwrap();
     let timestamp = Timestamp {
         seconds: now.as_secs() as i64,
         nanos: 0,
