@@ -61,7 +61,7 @@ struct Cnx(Address, f32);
 impl Eq for Cnx {}
 impl Ord for Cnx {
     fn cmp(&self, other: &Self) -> Ordering {
-        self.partial_cmp(other).unwrap()
+        f32::total_cmp(&self.1, &other.1)
     }
 }
 impl PartialEq for Cnx {
@@ -71,7 +71,7 @@ impl PartialEq for Cnx {
 }
 impl PartialOrd for Cnx {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        f32::partial_cmp(&self.1, &other.1)
+        Some(self.cmp(other))
     }
 }
 
@@ -147,9 +147,7 @@ impl<'a, DR: DataRetriever> HnswOps<'a, DR> {
             match best_so_far.map(|n| (n, self.similarity(n, query))) {
                 None => break None,
                 Some((_, score)) if score < self.tracker.min_score() => break None,
-                Some((n, score)) if filter.is_valid(n, score) && filter.passes_formula(n) => {
-                    break Some((n, score))
-                }
+                Some((n, score)) if filter.is_valid(n, score) && filter.passes_formula(n) => break Some((n, score)),
                 Some((down, _)) => {
                     let mut sorted_out: Vec<_> = layer.get_out_edges(down).collect();
                     sorted_out.sort_by(|a, b| b.1.total_cmp(&a.1));
@@ -202,18 +200,9 @@ impl<'a, DR: DataRetriever> HnswOps<'a, DR> {
                 _ => (),
             }
         }
-        ms_neighbours
-            .into_sorted_vec()
-            .into_iter()
-            .map(|Reverse(Cnx(n, d))| (n, d))
-            .collect()
+        ms_neighbours.into_sorted_vec().into_iter().map(|Reverse(Cnx(n, d))| (n, d)).collect()
     }
-    fn layer_insert(
-        &self,
-        x: Address,
-        layer: &mut RAMLayer,
-        entry_points: &[Address],
-    ) -> Vec<Address> {
+    fn layer_insert(&self, x: Address, layer: &mut RAMLayer, entry_points: &[Address]) -> Vec<Address> {
         use params::*;
         let neighbours = self.layer_search::<&RAMLayer>(x, layer, ef_construction(), entry_points);
         let neighbours = self.select_neighbours_heuristic(m_max(), neighbours);
@@ -231,9 +220,7 @@ impl<'a, DR: DataRetriever> HnswOps<'a, DR> {
         for crnt in needs_repair {
             let edges = layer.take_out_edges(crnt);
             let neighbours = self.select_neighbours_heuristic(m_max(), edges);
-            neighbours
-                .into_iter()
-                .for_each(|(y, edge)| layer.add_edge(crnt, edge, y));
+            neighbours.into_iter().for_each(|(y, edge)| layer.add_edge(crnt, edge, y));
         }
         result
     }
@@ -257,50 +244,6 @@ impl<'a, DR: DataRetriever> HnswOps<'a, DR> {
         }
     }
 
-    // Brute-force search.
-    pub fn brute_force_search(
-        &self,
-        query: Address,
-        k_neighbours: usize,
-        with_filter: FormulaFilter,
-        with_duplicates: bool,
-    ) -> Neighbours {
-        let no_blocked = HashSet::with_capacity(0);
-        let mut result = BinaryHeap::with_capacity(k_neighbours);
-        let mut rep_counter = RepCounter::new(!with_duplicates);
-
-        for addr in with_filter.matching_nodes.iter().copied() {
-            let addr = Address(addr as usize);
-            let score = self.tracker.similarity(addr, query);
-            let filter = NodeFilter {
-                tracker: self.tracker,
-                filter: &with_filter,
-                blocked_addresses: &no_blocked,
-                vec_counter: &rep_counter,
-            };
-            if score < self.tracker.min_score() || !filter.is_valid(addr, score) {
-                continue;
-            } else if result.len() < k_neighbours {
-                rep_counter.add(self.tracker.get_vector(addr));
-                result.push(Reverse(Cnx(addr, score)));
-            } else {
-                // Is safe to unwrap because k >= k_neighbours
-                let Reverse(Cnx(_, min_score)) = result.peek().copied().unwrap();
-                if min_score < score {
-                    result.pop();
-                    rep_counter.add(self.tracker.get_vector(addr));
-                    result.push(Reverse(Cnx(addr, score)));
-                }
-            }
-        }
-        // Moving from heap to sorted vec, k*log(k)
-        let mut as_sorted_vec = Vec::new();
-        while let Some(Reverse(Cnx(addr, score))) = result.pop() {
-            as_sorted_vec.push((addr, score));
-        }
-        as_sorted_vec
-    }
-
     pub fn search<H: Hnsw>(
         &self,
         query: Address,
@@ -313,13 +256,6 @@ impl<'a, DR: DataRetriever> HnswOps<'a, DR> {
             return Neighbours::with_capacity(0);
         }
 
-        // If we have filters, we check how many nodes are matching those filters using FST
-        // If the number is low, we don't use HNSW and return right away those nodes
-        let filter_ratio = with_filter.matching_ratio().unwrap_or(f64::MAX);
-        if filter_ratio < 0.1 {
-            return self.brute_force_search(query, k_neighbours, with_filter, with_duplicates);
-        }
-
         let Some(entry_point) = hnsw.get_entry_point() else {
             return Neighbours::default();
         };
@@ -351,9 +287,7 @@ impl<'a, DR: DataRetriever> HnswOps<'a, DR> {
                 blocked_addresses: &sol_addresses,
                 vec_counter: &vec_counter,
             };
-            let Some((addr, score)) =
-                self.closest_up_node(addr, query, hnsw.get_layer(0), node_filter)
-            else {
+            let Some((addr, score)) = self.closest_up_node(addr, query, hnsw.get_layer(0), node_filter) else {
                 continue;
             };
             filtered_result.push((addr, score));
