@@ -20,8 +20,8 @@
 use std::path::PathBuf;
 
 use crossbeam::channel::Sender;
+use nucliadb_core::fs_state;
 use nucliadb_core::tracing::*;
-use nucliadb_core::{fs_state, Channel};
 
 use super::merger::{MergeQuery, MergeRequest};
 use super::State;
@@ -32,7 +32,6 @@ pub(crate) struct Worker {
     location: PathBuf,
     sender: Sender<Journal>,
     similarity: Similarity,
-    channel: Channel,
 }
 impl MergeQuery for Worker {
     fn do_work(&self) -> VectorR<()> {
@@ -40,17 +39,11 @@ impl MergeQuery for Worker {
     }
 }
 impl Worker {
-    pub(crate) fn request(
-        location: PathBuf,
-        sender: Sender<Journal>,
-        similarity: Similarity,
-        channel: Channel,
-    ) -> MergeRequest {
+    pub(crate) fn request(location: PathBuf, sender: Sender<Journal>, similarity: Similarity) -> MergeRequest {
         Box::new(Worker {
             similarity,
             location,
             sender,
-            channel,
         })
     }
     fn work(&self) -> VectorR<()> {
@@ -59,14 +52,11 @@ impl Worker {
         info!("{subscriber:?} is ready to perform a merge");
         let state: State = fs_state::load_state(subscriber)?;
         let Some(work) = state.current_work_unit().map(|work| {
-            work.iter()
-                .rev()
-                .map(|journal| (state.delete_log(*journal), journal.id()))
-                .collect::<Vec<_>>()
+            work.iter().rev().map(|journal| (state.delete_log(*journal), journal.id())).collect::<Vec<_>>()
         }) else {
             return Ok(());
         };
-        let new_dp = DataPoint::merge(subscriber, &work, self.similarity, self.channel)?;
+        let new_dp = DataPoint::merge(subscriber, &work, self.similarity)?;
         let new_dp_id = new_dp.get_id();
         if self.sender.send(new_dp.journal()).is_err() {
             // If the sender has been deallocated this data point becomes garbage,
