@@ -23,15 +23,16 @@ use std::time::Instant;
 use nucliadb_core::prelude::*;
 use nucliadb_core::protos::prost::Message;
 use nucliadb_core::protos::{
-    DocumentScored, DocumentVectorIdentifier, SentenceMetadata, VectorSearchRequest,
-    VectorSearchResponse,
+    DocumentScored, DocumentVectorIdentifier, SentenceMetadata, VectorSearchRequest, VectorSearchResponse,
 };
 use nucliadb_core::tracing::{self, *};
+use nucliadb_core::vectors::*;
 use nucliadb_procs::measure;
 
 use crate::data_point_provider::*;
-use crate::formula::{AtomClause, CompoundClause, Formula};
+use crate::formula::{AtomClause, BooleanOperator, Clause, CompoundClause, Formula};
 use crate::indexset::IndexSet;
+use crate::service::query_io;
 
 impl<'a> SearchRequest for (usize, &'a VectorSearchRequest, Formula) {
     fn with_duplicates(&self) -> bool {
@@ -78,15 +79,10 @@ impl VectorReader for VectorReaderService {
             }
         }
     }
-}
-
-impl ReaderChild for VectorReaderService {
-    type Request = VectorSearchRequest;
-    type Response = VectorSearchResponse;
 
     #[measure(actor = "vectors", metric = "search")]
     #[tracing::instrument(skip_all)]
-    fn search(&self, request: &Self::Request) -> NodeResult<Self::Response> {
+    fn search(&self, request: &ProtosRequest, context: &VectorsContext) -> NodeResult<ProtosResponse> {
         let time = Instant::now();
 
         let id = Some(&request.id);
@@ -97,29 +93,25 @@ impl ReaderChild for VectorReaderService {
         let indexet_slock = self.indexset.get_slock()?;
         let index_slock = self.index.get_slock()?;
 
-        let key_filters = request
-            .key_filters
-            .iter()
-            .cloned()
-            .map(AtomClause::key_prefix);
-        let paragraph_labels = request
-            .paragraph_labels
-            .iter()
-            .cloned()
-            .map(AtomClause::label);
+        let key_filters = request.key_filters.iter().cloned().map(AtomClause::key_prefix);
+        let field_labels = request.field_labels.iter().cloned().map(AtomClause::label);
         let mut formula = Formula::new();
-        request
-            .field_labels
-            .iter()
-            .cloned()
-            .map(AtomClause::label)
-            .for_each(|c| formula.extend(c));
+
+        if !request.field_labels.is_empty() {
+            let field_atoms = field_labels.map(Clause::Atom).collect();
+            let field_clause = CompoundClause::new(BooleanOperator::And, field_atoms);
+            formula.extend(field_clause);
+        }
 
         if key_filters.len() > 0 {
-            formula.extend(CompoundClause::new(key_filters.collect()));
+            let clause_labels = key_filters.map(Clause::Atom).collect();
+            let key_clause = CompoundClause::new(BooleanOperator::Or, clause_labels);
+            formula.extend(key_clause);
         }
-        for paragraph_label in paragraph_labels {
-            formula.extend(paragraph_label);
+
+        if let Some(filter) = context.filtering_formula.as_ref() {
+            let clause = query_io::map_expression(filter);
+            formula.extend(clause);
         }
 
         let search_request = (total_to_get, request, formula);
@@ -130,17 +122,11 @@ impl ReaderChild for VectorReaderService {
             debug!("{id:?} - No vectorset specified, searching in the main index");
             self.index.search(&search_request, &index_slock)?
         } else if let Some(index) = self.indexset.get(&request.vector_set, &indexet_slock)? {
-            debug!(
-                "{id:?} - vectorset specified and found, searching on {}",
-                request.vector_set
-            );
+            debug!("{id:?} - vectorset specified and found, searching on {}", request.vector_set);
             let lock = index.get_slock()?;
             index.search(&search_request, &lock)?
         } else {
-            debug!(
-                "{id:?} - A was vectorset specified, but not found. {} is not a vectorset",
-                request.vector_set
-            );
+            debug!("{id:?} - A was vectorset specified, but not found. {} is not a vectorset", request.vector_set);
             vec![]
         };
         let v = time.elapsed().as_millis();
@@ -200,7 +186,9 @@ impl TryFrom<Neighbour> for DocumentScored {
         Ok(DocumentScored {
             labels,
             metadata,
-            doc_id: Some(DocumentVectorIdentifier { id }),
+            doc_id: Some(DocumentVectorIdentifier {
+                id,
+            }),
             score: neighbour.score(),
         })
     }
@@ -318,11 +306,12 @@ mod tests {
             with_duplicates: true,
             ..Default::default()
         };
-        let result = reader.search(&request).unwrap();
+        let context = VectorsContext::default();
+        let result = reader.search(&request, &context).unwrap();
         assert_eq!(result.documents.len(), 4);
 
         request.key_filters = vec!["DOC/KEY/0".to_string()];
-        let result = reader.search(&request).unwrap();
+        let result = reader.search(&request, &context).unwrap();
         assert_eq!(result.documents.len(), 0);
     }
 
@@ -398,7 +387,8 @@ mod tests {
             with_duplicates: true,
             ..Default::default()
         };
-        let result = reader.search(&request).unwrap();
+        let context = VectorsContext::default();
+        let result = reader.search(&request, &context).unwrap();
         assert_eq!(result.documents.len(), 4);
 
         let request = VectorSearchRequest {
@@ -411,7 +401,7 @@ mod tests {
             with_duplicates: false,
             ..Default::default()
         };
-        let result = reader.search(&request).unwrap();
+        let result = reader.search(&request, &context).unwrap();
         let no_nodes = reader.count("").unwrap();
         assert_eq!(no_nodes, 4);
         assert_eq!(result.documents.len(), 3);
@@ -428,7 +418,7 @@ mod tests {
             min_score: 900.0,
             ..Default::default()
         };
-        let result = reader.search(&request).unwrap();
+        let result = reader.search(&request, &context).unwrap();
         let no_nodes = reader.count("").unwrap();
         assert_eq!(no_nodes, 4);
         assert_eq!(result.documents.len(), 0);
@@ -443,7 +433,7 @@ mod tests {
             with_duplicates: false,
             ..Default::default()
         };
-        assert!(reader.search(&bad_request).is_err());
+        assert!(reader.search(&bad_request, &context).is_err());
     }
 
     #[test]
@@ -455,10 +445,8 @@ mod tests {
             vectorset: dir.path().join("vectorset"),
             channel: Channel::EXPERIMENTAL,
         };
-        let raw_sentences = [
-            ("DOC/KEY/1/1".to_string(), vec![1.0, 2.0, 3.0]),
-            ("DOC/KEY/1/2".to_string(), vec![1.0, 2.0, 3.0]),
-        ];
+        let raw_sentences =
+            [("DOC/KEY/1/1".to_string(), vec![1.0, 2.0, 3.0]), ("DOC/KEY/1/2".to_string(), vec![1.0, 2.0, 3.0])];
         let resource_id = ResourceId {
             shard_id: "DOC".to_string(),
             uuid: "DOC/KEY".to_string(),
@@ -515,7 +503,8 @@ mod tests {
             with_duplicates: true,
             ..Default::default()
         };
-        let result = reader.search(&request).unwrap();
+        let context = VectorsContext::default();
+        let result = reader.search(&request, &context).unwrap();
         assert_eq!(result.documents.len(), 2);
 
         let request = VectorSearchRequest {
@@ -528,7 +517,7 @@ mod tests {
             with_duplicates: false,
             ..Default::default()
         };
-        let result = reader.search(&request).unwrap();
+        let result = reader.search(&request, &context).unwrap();
         assert_eq!(result.documents.len(), 1);
     }
 }
