@@ -28,7 +28,9 @@ use nucliadb_core::protos::prost::Message;
 use nucliadb_core::protos::resource::ResourceStatus;
 use nucliadb_core::protos::{Resource, ResourceId, VectorSetId, VectorSimilarity};
 use nucliadb_core::tracing::{self, *};
-use nucliadb_core::{metrics, Channel, IndexFiles, RawReplicaState};
+use nucliadb_core::vectors::MergeMetrics;
+use nucliadb_core::vectors::*;
+use nucliadb_core::{metrics, IndexFiles, RawReplicaState};
 use nucliadb_procs::measure;
 
 use crate::data_point::{DataPoint, Elem, LabelDictionary};
@@ -45,7 +47,6 @@ impl IndexKeyCollector for Vec<String> {
 pub struct VectorWriterService {
     index: Index,
     indexset: IndexSet,
-    channel: Channel,
     config: VectorConfig,
 }
 
@@ -56,6 +57,22 @@ impl Debug for VectorWriterService {
 }
 
 impl VectorWriter for VectorWriterService {
+    #[measure(actor = "vectors", metric = "merge")]
+    #[tracing::instrument(skip_all)]
+    fn merge(&mut self) -> NodeResult<MergeMetrics> {
+        let time = Instant::now();
+
+        let lock = self.index.get_slock()?;
+        let inner_metrics = self.index.force_merge(&lock)?;
+
+        let took = time.elapsed().as_secs_f64();
+        debug!("Forcing a merge took: {took} s");
+        Ok(MergeMetrics {
+            merged: inner_metrics.merged,
+            left: inner_metrics.segments_left,
+        })
+    }
+
     #[measure(actor = "vectors", metric = "list_vectorsets")]
     #[tracing::instrument(skip_all)]
     fn list_vectorsets(&self) -> NodeResult<Vec<String>> {
@@ -74,11 +91,7 @@ impl VectorWriter for VectorWriterService {
 
     #[measure(actor = "vectors", metric = "add_vectorset")]
     #[tracing::instrument(skip_all)]
-    fn add_vectorset(
-        &mut self,
-        setid: &VectorSetId,
-        similarity: VectorSimilarity,
-    ) -> NodeResult<()> {
+    fn add_vectorset(&mut self, setid: &VectorSetId, similarity: VectorSimilarity) -> NodeResult<()> {
         let time = Instant::now();
 
         let id = setid.shard.as_ref().map(|s| &s.id);
@@ -86,8 +99,7 @@ impl VectorWriter for VectorWriterService {
         let indexid = setid.vectorset.as_str();
         let similarity = similarity.into();
         let indexset_elock = self.indexset.get_elock()?;
-        self.indexset
-            .get_or_create(indexid, similarity, &indexset_elock)?;
+        self.indexset.get_or_create(indexid, similarity, &indexset_elock)?;
         self.indexset.commit(indexset_elock)?;
 
         let took = time.elapsed().as_secs_f64();
@@ -113,9 +125,7 @@ impl VectorWriter for VectorWriterService {
 
         Ok(())
     }
-}
 
-impl WriterChild for VectorWriterService {
     #[measure(actor = "vectors", metric = "count")]
     #[tracing::instrument(skip_all)]
     fn count(&self) -> NodeResult<usize> {
@@ -167,13 +177,7 @@ impl WriterChild for VectorWriterService {
                 let field = &[paragraph_field.clone()];
                 for index in paragraph.paragraphs.values() {
                     let labels = LabelDictionary::new(
-                        resource
-                            .labels
-                            .iter()
-                            .chain(index.labels.iter())
-                            .chain(field.iter())
-                            .cloned()
-                            .collect(),
+                        resource.labels.iter().chain(index.labels.iter()).chain(field.iter()).cloned().collect(),
                     );
                     for (key, sentence) in index.sentences.iter().clone() {
                         let key = key.to_string();
@@ -198,13 +202,10 @@ impl WriterChild for VectorWriterService {
         }
 
         let new_dp = if !elems.is_empty() {
-            Some(DataPoint::new(
-                self.index.location(),
-                elems,
-                Some(temporal_mark),
-                self.index.metadata().similarity,
-                self.channel,
-            )?)
+            let location = self.index.location();
+            let time = Some(temporal_mark);
+            let similarity = self.index.metadata().similarity;
+            Some(DataPoint::new(location, elems, time, similarity)?)
         } else {
             None
         };
@@ -239,12 +240,10 @@ impl WriterChild for VectorWriterService {
         debug!("{id:?} - Delete requests for indexes in the set: starts {v} ms");
 
         let indexset_slock = self.indexset.get_slock()?;
-        let index_iter = resource.vectors_to_delete.iter().flat_map(|(k, v)| {
-            self.indexset
-                .get(k, &indexset_slock)
-                .transpose()
-                .map(|i| (v, i))
-        });
+        let index_iter = resource
+            .vectors_to_delete
+            .iter()
+            .flat_map(|(k, v)| self.indexset.get(k, &indexset_slock).transpose().map(|i| (v, i)));
         for (vectorlist, index) in index_iter {
             let mut index = index?;
             let index_lock = index.get_slock()?;
@@ -288,13 +287,7 @@ impl WriterChild for VectorWriterService {
             } else if !elems.is_empty() {
                 let similarity = index.metadata().similarity;
                 let location = index.location();
-                let new_dp = DataPoint::new(
-                    location,
-                    elems,
-                    Some(temporal_mark),
-                    similarity,
-                    self.channel,
-                )?;
+                let new_dp = DataPoint::new(location, elems, Some(temporal_mark), similarity)?;
                 let lock = index.get_slock()?;
                 match index.add(new_dp, &lock) {
                     Ok(_) => index.commit(&lock)?,
@@ -348,14 +341,8 @@ impl WriterChild for VectorWriterService {
     fn get_index_files(&self, ignored_segment_ids: &[String]) -> NodeResult<IndexFiles> {
         // Should be called along with a lock at a higher level to be safe
         let mut metadata_files = HashMap::new();
-        metadata_files.insert(
-            "vectors/state.bincode".to_string(),
-            fs::read(self.config.path.join("state.bincode"))?,
-        );
-        metadata_files.insert(
-            "vectors/metadata.json".to_string(),
-            fs::read(self.config.path.join("metadata.json"))?,
-        );
+        metadata_files.insert("vectors/state.bincode".to_string(), fs::read(self.config.path.join("state.bincode"))?);
+        metadata_files.insert("vectors/metadata.json".to_string(), fs::read(self.config.path.join("metadata.json"))?);
 
         let mut files = Vec::new();
 
@@ -366,38 +353,20 @@ impl WriterChild for VectorWriterService {
             files.push(format!("vectors/{}/index.hnsw", segment_id));
             files.push(format!("vectors/{}/journal.json", segment_id));
             files.push(format!("vectors/{}/nodes.kv", segment_id));
-
-            let fst_path = self.index.location.join(format!("{}/fst", segment_id));
-            if fst_path.exists() {
-                files.push(format!("vectors/{}/fst/keys.fst", segment_id));
-                files.push(format!("vectors/{}/fst/labels.fst", segment_id));
-                files.push(format!("vectors/{}/fst/labels.idx", segment_id));
-            }
         }
 
         let vectorsets = self.list_vectorsets()?;
         if !vectorsets.is_empty() {
-            metadata_files.insert(
-                "vectorset/state.bincode".to_string(),
-                fs::read(self.config.vectorset.join("state.bincode"))?,
-            );
+            metadata_files
+                .insert("vectorset/state.bincode".to_string(), fs::read(self.config.vectorset.join("state.bincode"))?);
             for vs in vectorsets {
-                for segment_id in
-                    self.get_segment_ids_for_vectorset(&self.config.vectorset.join(vs.clone()))?
-                {
+                for segment_id in self.get_segment_ids_for_vectorset(&self.config.vectorset.join(vs.clone()))? {
                     if ignored_segment_ids.contains(&segment_id) {
                         continue;
                     }
                     files.push(format!("vectorset/{}/{}/index.hnsw", vs, segment_id));
                     files.push(format!("vectorset/{}/{}/journal.json", vs, segment_id));
                     files.push(format!("vectorset/{}/{}/nodes.kv", vs, segment_id));
-
-                    let fst_path = self.config.vectorset.join(format!("{}/fst", segment_id));
-                    if fst_path.exists() {
-                        files.push(format!("vectors/{}/fst/keys.fst", segment_id));
-                        files.push(format!("vectors/{}/fst/labels.fst", segment_id));
-                        files.push(format!("vectors/{}/fst/labels.idx", segment_id));
-                    }
                 }
                 metadata_files.insert(
                     format!("vectorset/{}/state.bincode", vs),
@@ -461,10 +430,7 @@ impl VectorWriterService {
             Err(node_error!("Shard does exist".to_string()))
         } else {
             let Some(similarity) = config.similarity.map(|i| i.into()) else {
-                return Err(node_error!(
-                    "A similarity must be specified, {:?}",
-                    config.similarity
-                ));
+                return Err(node_error!("A similarity must be specified, {:?}", config.similarity));
             };
             Ok(VectorWriterService {
                 index: Index::new(
@@ -475,7 +441,6 @@ impl VectorWriterService {
                     },
                 )?,
                 indexset: IndexSet::new(indexset)?,
-                channel: config.channel,
                 config: config.clone(),
             })
         }
@@ -491,7 +456,6 @@ impl VectorWriterService {
             Ok(VectorWriterService {
                 index: Index::open(path)?,
                 indexset: IndexSet::new(indexset)?,
-                channel: config.channel,
                 config: config.clone(),
             })
         }
@@ -514,21 +478,18 @@ impl VectorWriterService {
 
 #[cfg(test)]
 mod tests {
-    use std::collections::{HashMap, HashSet};
-
     use nucliadb_core::protos::resource::ResourceStatus;
     use nucliadb_core::protos::{
-        IndexParagraph, IndexParagraphs, Resource, ResourceId, UserVector, UserVectors,
-        VectorSearchRequest, VectorSentence, VectorSimilarity,
+        IndexParagraph, IndexParagraphs, Resource, ResourceId, UserVector, UserVectors, VectorSearchRequest,
+        VectorSentence, VectorSimilarity,
     };
+    use nucliadb_core::Channel;
+    use std::collections::{HashMap, HashSet};
     use tempfile::TempDir;
 
     use super::*;
     use crate::service::reader::VectorReaderService;
-    fn create_vector_set(
-        writer: &mut VectorWriterService,
-        set_name: String,
-    ) -> (String, UserVectors) {
+    fn create_vector_set(writer: &mut VectorWriterService, set_name: String) -> (String, UserVectors) {
         let label = format!("{set_name}/label");
         let key = format!("{set_name}/key");
         let vector = vec![1.0, 3.0, 4.0];
@@ -558,11 +519,7 @@ mod tests {
         };
 
         let mut writer = VectorWriterService::start(&vsc).expect("Error starting vector writer");
-        assert_eq!(writer.channel, Channel::EXPERIMENTAL);
-
-        let indexes: HashMap<_, _> = (0..10)
-            .map(|i| create_vector_set(&mut writer, i.to_string()))
-            .collect();
+        let indexes: HashMap<_, _> = (0..10).map(|i| create_vector_set(&mut writer, i.to_string())).collect();
         let keys: HashSet<_> = indexes.keys().cloned().collect();
         let resource = Resource {
             vectors: indexes,
@@ -583,19 +540,20 @@ mod tests {
             with_duplicates: false,
             ..Default::default()
         };
-        let results = reader.search(&request).unwrap();
+        let context = VectorsContext::default();
+        let results = reader.search(&request, &context).unwrap();
         let id = results.documents[0].doc_id.clone().unwrap().id;
         assert_eq!(results.documents.len(), 1);
         assert_eq!(id, "4/key");
 
         // Same set, but no label match
         request.field_labels = vec!["5/label".to_string()];
-        let results = reader.search(&request).unwrap();
+        let results = reader.search(&request, &context).unwrap();
         assert_eq!(results.documents.len(), 0);
 
         // Invalid set
         request.vector_set = "not a set".to_string();
-        let results = reader.search(&request).unwrap();
+        let results = reader.search(&request, &context).unwrap();
         assert_eq!(results.documents.len(), 0);
 
         // Remove set 4
@@ -613,7 +571,7 @@ mod tests {
         // Now vectorset 4 is no longer available
         request.vector_set = "4".to_string();
         request.field_labels = vec!["4/label".to_string()];
-        let results = reader.search(&request).unwrap();
+        let results = reader.search(&request, &context).unwrap();
         assert_eq!(results.documents.len(), 0);
     }
 
@@ -755,9 +713,6 @@ mod tests {
             expected_files.push(format!("vectors/{}/index.hnsw", segment));
             expected_files.push(format!("vectors/{}/journal.json", segment));
             expected_files.push(format!("vectors/{}/nodes.kv", segment));
-            expected_files.push(format!("vectors/{}/fst/keys.fst", segment));
-            expected_files.push(format!("vectors/{}/fst/labels.fst", segment));
-            expected_files.push(format!("vectors/{}/fst/labels.idx", segment));
         }
         assert_eq!(index_files.files, expected_files);
         assert_eq!(index_files.metadata_files.len(), 2);
